package rate;

import java.util.*;
import java.io.*;
import org.apache.commons.collections.SequencedHashMap;
import org.apache.commons.collections.ExtendedProperties;

public class RateController extends Thread {
	protected RateModel model;
	protected RateView view;
	protected int interval;

	public RateController(String homeDir) {
		try {
			ExtendedProperties props = new ExtendedProperties();

			props.load(new FileInputStream(homeDir
					+ System.getProperty("file.separator") + "sys.properties"));
			String title = props.getString("title");
			String viewClass = props.getString("viewClass");
			String url = props.getString("url");
			String pattern = props.getString("pattern");
			Vector currencies = props.getVector("currencies");

			props.load(new FileInputStream(homeDir
					+ System.getProperty("file.separator") + "app.properties"));
			Vector viewCurrencies = props.getVector("viewCurrencies");
			interval = props.getInt("interval") * 1000;
			String proxyHost = props.getString("proxyHost");
			if (proxyHost != null && proxyHost.length() > 0) {
				System.setProperty("proxyHost", proxyHost);
			}
			String proxyPort = props.getString("proxyPort");
			if (proxyPort != null && proxyPort.length() > 0) {
				System.setProperty("proxyPort", proxyPort);
			}

			model = new RateModel(url, pattern, currencies, viewCurrencies);
			view = (RateView) (Class.forName(viewClass).newInstance());
			view.init(title, this);
		} catch (FileNotFoundException e) {
			e.printStackTrace();
			System.exit(-1);
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(-1);
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(-1);
		}
	}

	public SequencedHashMap getData() throws RateException {
		return model.getData();
	}

	public void run() {
		while (true) {
			try {
				sleep(interval);
			} catch (InterruptedException e) {
				System.exit(0);
			}

			view.update();
		}
	}
}